netapp_ontap.models.consistency_group_namespace_space_guarantee API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_namespace_space_guarantee`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupNamespaceSpaceGuaranteeSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupNamespaceSpaceGuarantee object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `requested: bool GET POST PATCH`

    The requested space reservation policy for the NVMe namespace. If true, a space reservation is requested for the namespace; if false, the namespace is thin provisioned. Guaranteeing a space reservation request for a namespace requires that the volume in which the namespace resides also be space reserved and that the fractional reserve for the volume be 100%.
    The space reservation policy for an NVMe namespace is determined by ONTAP.

  `reserved: bool GET`

    Reports if the NVMe namespace is space guaranteed.
    This property is true if a space guarantee is requested and the containing volume and aggregate support the request. This property is false if a space guarantee is not requested or if a space guarantee is requested and either the containing volume and aggregate do not support the request.